@@ -22,6 +22,10 @@
  *
  */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdint.h>
 #include <X11/Xlibint.h>
 #include <X11/extensions/XI2proto.h>
@@ -71,6 +75,7 @@ XIQueryDevice(Display *dpy, int deviceid, int *ndevices_return)
     for (i = 0; i < reply.num_devices; i++)
     {
         int             nclasses;
+        size_t          sz;
         XIDeviceInfo    *lib = &info[i];
         xXIDeviceInfo   *wire = (xXIDeviceInfo*)ptr;
 
@@ -86,7 +91,8 @@ XIQueryDevice(Display *dpy, int deviceid, int *ndevices_return)
         strncpy(lib->name, ptr, wire->name_len);
         ptr += ((wire->name_len + 3)/4) * 4;
 
-        lib->classes = Xmalloc(size_classes((xXIAnyInfo*)ptr, nclasses));
+        sz = size_classes((xXIAnyInfo*)ptr, nclasses);
+        lib->classes = Xmalloc(sz);
         ptr += copy_classes(lib, (xXIAnyInfo*)ptr, &nclasses);
         /* We skip over unused classes */
         lib->num_classes = nclasses;
